@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,17 +18,19 @@ from typing import (
     AsyncIterator,
     Awaitable,
     Callable,
+    Iterator,
+    Optional,
     Sequence,
     Tuple,
-    Optional,
-    Iterator,
 )
 
-from google.cloud.websecurityscanner_v1beta.types import crawled_url
-from google.cloud.websecurityscanner_v1beta.types import finding
-from google.cloud.websecurityscanner_v1beta.types import scan_config
-from google.cloud.websecurityscanner_v1beta.types import scan_run
-from google.cloud.websecurityscanner_v1beta.types import web_security_scanner
+from google.cloud.websecurityscanner_v1beta.types import (
+    crawled_url,
+    finding,
+    scan_config,
+    scan_run,
+    web_security_scanner,
+)
 
 
 class ListScanConfigsPager:
