@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,6 @@
 #
 import proto  # type: ignore
 
-
 __protobuf__ = proto.module(
     package="google.cloud.websecurityscanner.v1beta",
     manifest={
@@ -41,8 +40,14 @@ class Form(proto.Message):
             vulnerability.
     """
 
-    action_uri = proto.Field(proto.STRING, number=1,)
-    fields = proto.RepeatedField(proto.STRING, number=2,)
+    action_uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    fields = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
 
 
 class OutdatedLibrary(proto.Message):
@@ -58,9 +63,18 @@ class OutdatedLibrary(proto.Message):
             vulnerabilities in the library.
     """
 
-    library_name = proto.Field(proto.STRING, number=1,)
-    version = proto.Field(proto.STRING, number=2,)
-    learn_more_urls = proto.RepeatedField(proto.STRING, number=3,)
+    library_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    version = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    learn_more_urls = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ViolatingResource(proto.Message):
@@ -74,8 +88,14 @@ class ViolatingResource(proto.Message):
             URL of this violating resource.
     """
 
-    content_type = proto.Field(proto.STRING, number=1,)
-    resource_url = proto.Field(proto.STRING, number=2,)
+    content_type = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    resource_url = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class VulnerableParameters(proto.Message):
@@ -86,7 +106,10 @@ class VulnerableParameters(proto.Message):
             The vulnerable parameter names.
     """
 
-    parameter_names = proto.RepeatedField(proto.STRING, number=1,)
+    parameter_names = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
 
 
 class VulnerableHeaders(proto.Message):
@@ -109,11 +132,25 @@ class VulnerableHeaders(proto.Message):
                 Header value.
         """
 
-        name = proto.Field(proto.STRING, number=1,)
-        value = proto.Field(proto.STRING, number=2,)
+        name = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        value = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
-    headers = proto.RepeatedField(proto.MESSAGE, number=1, message=Header,)
-    missing_headers = proto.RepeatedField(proto.MESSAGE, number=2, message=Header,)
+    headers = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=Header,
+    )
+    missing_headers = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=Header,
+    )
 
 
 class Xss(proto.Message):
@@ -128,8 +165,14 @@ class Xss(proto.Message):
             breakage.
     """
 
-    stack_traces = proto.RepeatedField(proto.STRING, number=1,)
-    error_message = proto.Field(proto.STRING, number=2,)
+    stack_traces = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    error_message = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
